# processamento-imagens-py

Description. 
The package processamento-imagens-py is used to:
	Processamento
		- Histogram matching
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram
## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install processamento-imagens-py

```bash
pip install processamento-imagens-py
```
## Author
Guilherme

## License
[MIT](https://choosealicense.com/licenses/mit/)